@@ -4,7 +4,7 @@
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 #pragma once
-#include <Item>
+#include <Akonadi/Item>
 #include <QDialog>
 class QListWidget;
 class QLabel;
@@ -19,7 +19,7 @@ class NotesAgentAlarmDialog : public QDialog
     Q_OBJECT
 public:
     explicit NotesAgentAlarmDialog(QWidget *parent = nullptr);
-    ~NotesAgentAlarmDialog();
+    ~NotesAgentAlarmDialog() override;
 
     void addListAlarm(const Akonadi::Item::List &lstAlarm);
     void removeAlarm(const Akonadi::Item &note);
